pub struct GitHubClient { /* private fields */ }Expand description
Client for the GitHub REST API, focused on issue/PR comments.
Implementations
Sourceimpl GitHubClient
impl GitHubClient
Sourcepub fn new(base_url: &str, token: &str) -> Result<Self, GitHubError>
pub fn new(base_url: &str, token: &str) -> Result<Self, GitHubError>
Creates a new GitHubClient with the given token.
The base_url should be https://api.github.com for github.com
or https://github.example.com/api/v3 for GitHub Enterprise.
Sourcepub async fn list_comments(
&self,
owner: &str,
repo: &str,
pr_number: u64,
) -> Result<Vec<GitHubComment>, GitHubError>
pub async fn list_comments( &self, owner: &str, repo: &str, pr_number: u64, ) -> Result<Vec<GitHubComment>, GitHubError>
List comments on a pull request / issue.
Sourcepub async fn create_comment(
&self,
owner: &str,
repo: &str,
pr_number: u64,
body: &str,
) -> Result<GitHubComment, GitHubError>
pub async fn create_comment( &self, owner: &str, repo: &str, pr_number: u64, body: &str, ) -> Result<GitHubComment, GitHubError>
Create a new comment on a pull request / issue.
Sourcepub async fn update_comment(
&self,
owner: &str,
repo: &str,
comment_id: u64,
body: &str,
) -> Result<GitHubComment, GitHubError>
pub async fn update_comment( &self, owner: &str, repo: &str, comment_id: u64, body: &str, ) -> Result<GitHubComment, GitHubError>
Update an existing comment.
Sourcepub async fn find_perfgate_comment(
&self,
owner: &str,
repo: &str,
pr_number: u64,
) -> Result<Option<GitHubComment>, GitHubError>
pub async fn find_perfgate_comment( &self, owner: &str, repo: &str, pr_number: u64, ) -> Result<Option<GitHubComment>, GitHubError>
Find an existing perfgate comment on a PR by looking for the marker.
Sourcepub async fn upsert_comment(
&self,
owner: &str,
repo: &str,
pr_number: u64,
body: &str,
) -> Result<(GitHubComment, bool), GitHubError>
pub async fn upsert_comment( &self, owner: &str, repo: &str, pr_number: u64, body: &str, ) -> Result<(GitHubComment, bool), GitHubError>
Create or update the perfgate comment on a PR (idempotent).
If a comment with the perfgate marker already exists, it is updated. Otherwise, a new comment is created.
Returns (comment, created) where created is true if a new comment was made.